@@ -435,26 +435,34 @@ rbind.BlockedInfinitySparseMatrix <- function(x, y, ...) {
 ##' Returns the dimension of each valid subproblem
 ##'
 ##' Returns a list containing the dimensions of all valid subproblems.
-##'
 ##' @param x A distance specification to get the sub-dimensions of.
 ##' @return A list of the dimensions of each valid subproblem. Any subproblems with 0 controls
 ##' or 0 treatments will be ignored. The names of the entries in the list will be the names of the
 ##' subproblems, if they exist.
 ##' @export
+##' @docType methods
+##' @rdname subdim-methods
 subdim <- function(x) {
   UseMethod("subdim")
 }
 
+##' @method subdim InfinitySparseMatrix
+##' @rdname subdim-methods
 subdim.InfinitySparseMatrix <- function(x) {
   list(dim(x))
 }
 
+##' @method subdim matrix
+##' @rdname subdim-methods
 subdim.matrix <- function(x) {
   list(dim(x))
 }
 
+##' @method subdim BlockedInfinitySparseMatrix
+##' @rdname subdim-methods
 subdim.BlockedInfinitySparseMatrix <- function(x) {
-  out <- lapply(levels(x@groups), function(k) c(sum(row.names(x) %in% names(x@groups)[x@groups == k]), sum(colnames(x) %in% names(x@groups)[x@groups == k])))
+  out <- lapply(levels(x@groups), function(k) c(sum(row.names(x) %in% names(x@groups)[x@groups == k]),
+                                                sum(colnames(x) %in% names(x@groups)[x@groups == k])))
   names(out) <- levels(x@groups)
   # drop off any subproblems lacking at least one treatment/control
   out[unlist(lapply(out, function(t) all(t > 0)))]
@@ -469,22 +477,33 @@ subdim.BlockedInfinitySparseMatrix <- function(x) {
 ##' @param x Any distance object.
 ##' @return A list counting the number of eligible matches in the distance.
 ##' @export
+##' @docType methods
+##' @rdname num_eligible_matches-methods
 num_eligible_matches <- function(x) {
   UseMethod("num_eligible_matches")
 }
 
+##' @method num_eligible_matches optmatch.dlist
+##' @rdname num_eligible_matches-methods
 num_eligible_matches.optmatch.dlist <-function(x) {
   list(sum(is.finite(x)))
 }
 
+##' @method num_eligible_matches matrix
+##' @rdname num_eligible_matches-methods
 num_eligible_matches.matrix <- function(x) {
   list(sum(is.finite(x)))
 }
 
+##' @method num_eligible_matches InfinitySparseMatrix
+##' @rdname num_eligible_matches-methods
 num_eligible_matches.InfinitySparseMatrix <- function(x) {
   list(length(x@.Data))
 }
 
+##' @method num_eligible_matches BlockedInfinitySparseMatrix
+##' @usage \method{num_eligible_matches}{BlockedInfinitySparseMatrix}(x)
+##' @rdname num_eligible_matches-methods
 num_eligible_matches.BlockedInfinitySparseMatrix <- function(x) {
   out <- lapply(levels(x@groups), function(k) length(x[x@groups == k]@.Data))
   names(out) <- levels(x@groups)
