@@ -3,11 +3,13 @@
 ################################################################################
 
 library(testthat)
+library(biglm)
+library(survival)
 
 context("match_on function")
 
 test_that("Distances from glms", {
-  
+
   n <- 16
   Z <- numeric(n)
   Z[sample.int(n, n/2)] <- 1
@@ -16,12 +18,19 @@ test_that("Distances from glms", {
   B <- rep(c(0,1), n/2)
 
   test.glm <- glm(Z ~ X1 + X2 + B, family = binomial()) # the coefs should be zero or so
-   
+
   result.glm <- match_on(test.glm)
-  
+
   expect_true(validDistanceSpecification(result.glm))
   expect_equal(length(result.glm), (n/2)^2)
-  
+
+  # what about classes that inherit from glm?
+  class(test.glm) <- c("foo", class(test.glm))
+
+  result.foo <- match_on(test.glm)
+
+  expect_true(validDistanceSpecification(result.foo))
+  expect_equal(length(result.foo), (n/2)^2)
 })
 
 test_that("Distances from formulas", {
@@ -44,14 +53,14 @@ test_that("Distances from formulas", {
   expect_error(match_on(Z ~ 1, data = test.data))
 
   # checking diferent classes of responses
-  res.one <- match_on(Z ~ X1) 
+  res.one <- match_on(Z ~ X1)
   res.logical <- match_on(as.logical(Z) ~ X1)
   expect_equivalent(res.one, res.logical)
 
   res.factor <- match_on(as.factor(Z) ~ X1)
   expect_equivalent(res.one, res.factor)
 
-  # euclidean distances 
+  # euclidean distances
   # first, compute what the distances should be for the data.
   euclid <- as.matrix(dist(test.data[,-1], method = "euclidean", upper = T))
   z <- as.logical(Z)
@@ -59,6 +68,10 @@ test_that("Distances from formulas", {
   expect_true(all(abs(match_on(Z ~ X1 + X2 + B, method = "euclidean") - euclid) <
     .00001)) # there is some rounding error, but it is small
 
+  # passing a function name for method
+  expect_true(all(abs(match_on(Z ~ X1 + X2 + B, method = "compute_euclidean") - euclid) <
+    .00001)) # there is some rounding error, but it is small
+
 
   # excluding matches combined with a formula
   stratify <- exactMatch(Z ~ B)
@@ -76,10 +89,10 @@ test_that("Mahalanobis distance calcualtions", {
                         badf2 = c(rep(0,3), rep(1,7)))
 
   expect_error(match_on(Z ~ all1, data = badData), "contrasts can be applied only to factors with 2 or more levels")
-  
-  # even though the supplied data is a bad idea, it should work using the svd() decomposition  
+
+  # even though the supplied data is a bad idea, it should work using the svd() decomposition
   res <- match_on(Z ~ badf1 + badf2, data = badData)
-  
+
 })
 
 test_that("Distances from functions", {
@@ -88,11 +101,11 @@ test_that("Distances from functions", {
   X1 <- rep(c(1,2,3,4), each = n/4)
   B <- rep(c(0,1), n/2)
   test.data <- data.frame(Z, X1, B)
-  
+
   sdiffs <- function(index, data, z) {
     abs(data[index[,1], "X1"] - data[index[,2], "X1"])
   }
-  
+
   result.function <- match_on(sdiffs, z = Z, data = test.data)
   expect_equal(dim(result.function), c(8,8))
 
@@ -101,20 +114,20 @@ test_that("Distances from functions", {
   # | 3 2 |
 
   expect_equal(mean(result.function), 2)
- 
+
   # no treatment indicator
   expect_error(match_on(sdiffs, data = test.data))
 
   # no data
   expect_error(match_on(sdiffs, z = Z))
-  
+
 })
 
 ###### Using mad() instead of sd() for GLM distances
 ###
 ###result <- match_on(glm(pr ~ t1 + t2 + cost, data = nuclearplants, family = binomial()))
 ###
-#### this is an odd test, but a simple way to make sure mad is running, not SD(). 
+#### this is an odd test, but a simple way to make sure mad is running, not SD().
 #### I would like a better test of the actual values, but it works
 ###test(mean(result$m) > 2)
 ###
@@ -166,7 +179,6 @@ test_that("Errors for numeric vectors", {
 ###     )
 ###test(all.equal(unlist(result.combined), unlist(with(nuclearplants, match_on(pr ~ t1 + t2, structure.fmla=strat.fmla)))))
 test_that("Bigglm distances", {
-  if (require('biglm')) {
     n <- 16
     Z <- c(rep(0, n/2), rep(1, n/2))
     X1 <- rnorm(n, mean = 5)
@@ -179,8 +191,7 @@ test_that("Bigglm distances", {
 
     # compare to glm
     res.glm <- match_on(glm(Z ~ X1 + X2, data = test.data, family = binomial()))
-    expect_equivalent(res.bg, res.glm) 
-  }
+    expect_equivalent(res.bg, res.glm)
 })
 
 test_that("Numeric: simple differences of scores", {
@@ -197,7 +208,7 @@ test_that("Numeric: simple differences of scores", {
 
   expect_true(all(match_on(z * -2, z = z) == 2))
 
-  # proper errors 
+  # proper errors
   expect_error(match_on(scores), "treatment")
   expect_error(match_on(scores, z = c(1,2)), "length")
   expect_error(match_on(c(1,2,3,4), z = c(0,1,0,1)), "names")
@@ -229,11 +240,11 @@ test_that("Numeric: simple differences of scores", {
   # repeat with match_on
   expect_equal(length(match_on(scores, z = z, caliper = 1)), 28) # 6 * 6 - 8
   expect_equal(length(match_on(scores, z = z, caliper = 1.5)), 28)
-  
+
   # combine the caliper width with an within argument
   b <- rep(1:3, 4)
   ez <- exactMatch(z ~ b)
-  
+
   res <- match_on(scores, z = z, caliper = 1, within = ez)
   expect_equal(length(res), 9)
 
@@ -318,15 +329,14 @@ test_that("Issue #44", {
 
   # this is the test case from:
   # https://github.com/markmfredrickson/optmatch/issues/44
-  library(survival)
 
   coxps <- predict(coxph(Surv(start, stop, event) ~ age + year + transplant + cluster(id), data=heart))
   names(coxps) <- row.names(heart)
   coxmoA <- match_on(coxps, z = heart$event, caliper = 1)
-  expect_true(max(coxmoA) <= 1) 
-  
+  expect_true(max(coxmoA) <= 1)
+
   coxmoC <- match_on(coxps, within = exactMatch(event ~ transplant, data = heart), z = heart$event, caliper = 1)
-  expect_true(max(coxmoC) <= 1) 
+  expect_true(max(coxmoC) <= 1)
 
 })
 
@@ -345,3 +355,33 @@ test_that("Issue 48: caliper is a universal argument", {
   res.fmla <- match_on(Z ~ X, caliper = 1)
   expect_true(all(res.fmla <= 1))
 })
+
+# test_that("bayesglm, brglm", {
+# 
+#   # packaages are added at top of file
+#   data(nuclearplants)
+# 
+#   by <- bayesglm(pr ~ cost, data=nuclearplants, family=binomial)
+#   expect_true(all(class(by) == c("bayesglm", "glm", "lm")))
+#   m1 <- match_on(by, data=nuclearplants)
+#   expect_true(class(m1)[1] %in% c("InfinitySparseMatrix", "BlockedInfinitySparseMatrix", "DenseMatrix"))
+# 
+#   br <- brglm(pr ~ cost, data=nuclearplants, family=binomial, method="glm.fit")
+#   expect_true(all(class(br) == c("brglm", "glm", "lm")))
+#   m2 <- match_on(br, data=nuclearplants)
+#   expect_true(class(m2)[1] %in% c("InfinitySparseMatrix", "BlockedInfinitySparseMatrix", "DenseMatrix"))
+# })
+
+test_that("numeric standardization scale", {
+  n <- 16
+  Z <- numeric(n)
+  Z[sample.int(n, n/2)] <- 1
+  X1 <- rnorm(n, mean = 5)
+  X2 <- rnorm(n, mean = -2, sd = 2)
+  B <- rep(c(0,1), n/2)
+
+  test.glm <- glm(Z ~ X1 + X2 + B, family = binomial()) # the coefs should be zero or so
+
+  result.glm <- match_on(test.glm, standardization.scale=1)
+})
+
