@@ -8,13 +8,16 @@ stratumStructure(plantsfm)
 stratumStructure(plantsfm1)
 
 data(nuclearplants)
-psd <- pscore.dist(glm(pr~.-(pr+cost), family=binomial(),
-                       data=nuclearplants))
+psd <- match_on(glm(pr~.-(pr+cost), family=binomial(),
+                       data=nuclearplants),
+             standardization.scale = sd) # sd was standard in < 0.7-2
 stratumStructure(fullmatch(psd))
 stratumStructure(fm.psd.cal <- fullmatch(psd/(psd<.25)))
 
-psd2 <- pscore.dist(glm(pr~.-(pr+cost), family=binomial(),
-                       data=nuclearplants),structure.fmla=~pt)
+psd2 <- match_on(glm(pr~.-(pr+cost), family=binomial(),
+                       data=nuclearplants),
+              standardization.scale = sd,
+              within = exactMatch(pr ~ pt, nuclearplants))
 stratumStructure(fullmatch(psd2,min.controls=1,max.controls=1))
 stratumStructure(fullmatch(psd2,min.controls=3,max.controls=3))
 
